package com.isu.gaswellwatch.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.isu.gaswellwatch.annotation.OperationLog;
import com.isu.gaswellwatch.dto.RoleDTO;
import com.isu.gaswellwatch.dto.RoleEditDTO;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.service.RoleService;
import com.isu.gaswellwatch.vo.RoleVO;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;


@RestController
@RequestMapping("role")
public class RoleController {
    /**
     * 服务对象
     */
    @Resource
    private RoleService roleService;

    @GetMapping("/page")
    public Response<Page<RoleVO>> page(@RequestParam(defaultValue = "1") Integer currentPage,
                                       @RequestParam(defaultValue = "10") Integer pageSize,
                                       @RequestParam(required = false) String name){
        return Response.succeed(roleService.page(currentPage,pageSize,name));
    }

    @PostMapping("/add")
    @OperationLog(description = "新增角色",type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid RoleDTO roleDTO){
        roleService.add(roleDTO);
        return Response.succeed();
    }

    @PostMapping("/edit")
    @OperationLog(description = "修改角色",type = LogType.UPDATE)
    public Response<String> edit(@RequestBody @Valid RoleEditDTO roleEditDTO){
        roleService.edit(roleEditDTO);
        return Response.succeed();
    }

    @GetMapping("/delete")
    @OperationLog(description = "删除角色",type = LogType.DELETE)
    public Response<String> delete(@RequestParam Long id){
        roleService.delete(id);
        return Response.succeed();
    }
}

